@@ -107,6 +107,11 @@ class ChessPlayer:
         'game' is the game that has ended (Game).
         """
         pass
+    
+    def readyToMove(self):
+        """FIXME
+        """
+        pass
 
     # Public methods
 
@@ -385,11 +390,6 @@ class ChessGame:
         """
         assert(self.__whitePlayer is not None and self.__blackPlayer is not None)
         
-        # Disabled for now
-        #import network
-        #self.x = network.GameReporter('Test Game', 12345)
-        #print 'Reporting'
-
         # Load starting moves
         self.__currentPlayer = self.__whitePlayer
         for move in moves:
@@ -681,16 +681,34 @@ class ChessGame:
         for player in self.__players:
             player.onPieceMoved(piece, start, end, delete)
 
-class NetworkChessGame(ChessGame):
-    """
-    """
+if __name__ == '__main__':
+    game = ChessGame()
     
-    def move(self, player, move):
-        """Get a player to make a move.
+    import pgn
+    
+    p = pgn.PGN('black.pgn')
+    g = p.getGame(0)
+
+    class PGNPlayer(ChessPlayer):
+        __moveNumber = 1
         
-        'player' is the player making the move.
-        'move' is the move to make. It can be of the form:
-               A coordinate move in the form ((file0, rank0), (file1, rank1), promotionType) ((int, int), (int, int), chess.board.PIECE_TYPE) or
-               A SAN move (string).
-        """
-        # Send to the server
+        __isWhite = True
+        
+        def __init__(self, isWhite):
+            self.__isWhite = isWhite
+        
+        def readyToMove(self):
+            if self.__isWhite:
+                move = g.getWhiteMove(self.__moveNumber)
+            else:
+                move = g.getBlackMove(self.__moveNumber)
+            self.__moveNumber += 1
+            self.move(move)
+            
+    white = PGNPlayer(True)
+    black = PGNPlayer(False)
+    
+    game.setWhite(white)
+    game.setBlack(black)
+    
+    game.start()
