@@ -244,9 +244,9 @@ class GtkNewGameDialog:
                 errorText += _('Unable to find %s engine\n') % repr(g.black.type)
             self.__setCombo('black_difficulty_combo', g.black.level)
             # TODO: Others
-            
+
             # Change title for loaded games
-            if len(g.path) > 0:
+            if g.path is not None:
                 self.__gui.get_widget('new_game_dialog').set_title(_('Configure loaded game (%i moves)') % len(g.moves))
 
         # Display warning if missing the AIs
@@ -305,6 +305,8 @@ class GtkNewGameDialog:
         if self.__customName:
             name = self.__gui.get_widget('game_name_entry').get_text()
             if len(name) == 0:
+                # Next time the something changes generate a name
+                self.__customName = False
                 ready = False
 
         # Name the game based on the players
@@ -381,7 +383,8 @@ class GtkNewGameDialog:
         """Gtk+ callback"""
         if self.__checking:
             return
-        self.__customName = len(widget.get_text()) != 0
+        self.__customName = True
+        self.__testReady()
 
     def _on_time_changed(self, widget):
         """Gtk+ callback"""
@@ -470,7 +473,9 @@ class GtkLoadGameDialog:
         chooser= self.__gui.get_widget('filechooserwidget')
 
         if responseId == gtk.RESPONSE_OK or responseId == gtk.RESPONSE_YES:
-            glchess.config.set('load_directory', chooser.get_current_folder())
+            folder = chooser.get_current_folder()
+            if folder is not None:
+                glchess.config.set('load_directory', folder)
             error = self.__mainUI.feedback.loadGame(self.__getFilename(), responseId == gtk.RESPONSE_YES)
             if error is not None:
                 self.firstExpose = True
@@ -629,8 +634,10 @@ class GtkSaveGameDialog:
                 fname += '.pgn'
 
             # Save the directory we used
-            glchess.config.set('save_directory', chooser.get_current_folder())
-        
+            folder = chooser.get_current_folder()
+            if folder is not None:
+                glchess.config.set('save_directory', folder)
+
             error = self.__mainUI._saveView(self.__view, fname)
             if error is not None:
                 self.__setError(_('Unabled to save game'), error)
