@@ -2,7 +2,7 @@ import os, os.path
 import errno
 import gettext
 
-APP_DATA_DIR = os.path.join('/gnome/usr', 'share') 
+APP_DATA_DIR = os.path.join('/home/thomas/john6/test', 'share') 
 IMAGE_DIR = os.path.join(APP_DATA_DIR, 'pixmaps', 'gnome-sudoku')
 LOCALEDIR = os.path.join(APP_DATA_DIR, 'locale')
 GLADE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
@@ -16,7 +16,7 @@ import gtk.glade
 gtk.glade.bindtextdomain (DOMAIN, LOCALEDIR)
 gtk.glade.textdomain (DOMAIN)
 
-VERSION = "2.20.0.1"
+VERSION = "2.20.2"
 APPNAME = _("GNOME Sudoku")
 APPNAME_SHORT = _("Sudoku")
 COPYRIGHT = 'Copyright \xc2\xa9 2005-2007, Thomas M. Hinkle'
